@@ -104,7 +104,7 @@ bool LoginJobPrivate::sasl_interact()
                 interact->len = strlen((const char *)interact->result);
                 break;
             }
-            Q_FALLTHROUGH();
+            [[fallthrough]];
         case SASL_CB_USER:
             qCDebug(KIMAP_LOG) << "SASL_CB_[USER|AUTHNAME]: '" << userName << "'";
             interact->result = strdup(userName.toUtf8().constData());
@@ -391,7 +391,7 @@ void LoginJob::handleResponse(const Response &response)
         case LoginJobPrivate::Authenticate:
             sasl_dispose(&d->conn); // SASL authentication done
             // Fall through
-            Q_FALLTHROUGH();
+            [[fallthrough]];
         case LoginJobPrivate::Login:
             d->saveServerGreeting(response);
             emitResult(); // got an OK, command done
